@@ -40,6 +40,8 @@ import org.eclipse.che.commons.env.EnvironmentContext;
 import org.eclipse.che.workspace.infrastructure.kubernetes.CheServerKubernetesClientFactory;
 import org.eclipse.che.workspace.infrastructure.kubernetes.api.server.impls.KubernetesNamespaceMetaImpl;
 import org.eclipse.che.workspace.infrastructure.kubernetes.api.shared.KubernetesNamespaceMeta;
+import org.eclipse.che.workspace.infrastructure.kubernetes.authorization.AuthorizationChecker;
+import org.eclipse.che.workspace.infrastructure.kubernetes.authorization.PermissionsCleaner;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.KubernetesNamespaceFactory;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.configurator.NamespaceConfigurator;
 import org.eclipse.che.workspace.infrastructure.kubernetes.util.KubernetesSharedPool;
@@ -81,6 +83,8 @@ public class OpenShiftProjectFactory extends KubernetesNamespaceFactory {
       CheServerOpenshiftClientFactory cheServerOpenshiftClientFactory,
       PreferenceManager preferenceManager,
       KubernetesSharedPool sharedPool,
+      AuthorizationChecker authorizationChecker,
+      PermissionsCleaner permissionsCleaner,
       @Nullable @Named("che.infra.openshift.oauth_identity_provider")
           String oAuthIdentityProvider) {
     super(
@@ -93,7 +97,9 @@ public class OpenShiftProjectFactory extends KubernetesNamespaceFactory {
         namespaceConfigurators,
         cheServerKubernetesClientFactory,
         preferenceManager,
-        sharedPool);
+        sharedPool,
+        authorizationChecker,
+        permissionsCleaner);
     this.initWithCheServerSa = initWithCheServerSa;
     this.cheServerKubernetesClientFactory = cheServerKubernetesClientFactory;
     this.cheServerOpenshiftClientFactory = cheServerOpenshiftClientFactory;
@@ -105,6 +111,9 @@ public class OpenShiftProjectFactory extends KubernetesNamespaceFactory {
     OpenShiftProject osProject = get(identity);
     var subject = EnvironmentContext.getCurrent().getSubject();
     var userName = subject.getUserName();
+
+    validateAuthorization(osProject.getName(), userName);
+
     NamespaceResolutionContext resolutionCtx =
         new NamespaceResolutionContext(identity.getWorkspaceId(), subject.getUserId(), userName);
     Map<String, String> namespaceAnnotationsEvaluated =
