@@ -11,7 +11,6 @@
  */
 package org.eclipse.che.api.factory.server.bitbucket;
 
-import static com.google.common.base.Strings.isNullOrEmpty;
 import static java.lang.String.format;
 import static java.lang.String.valueOf;
 
@@ -179,21 +178,8 @@ public class BitbucketServerPersonalAccessTokenFetcher implements PersonalAccess
       }
     }
     try {
-      // Token is added manually by a user without token id. Validate only by requesting user info.
-      if (isNullOrEmpty(params.getScmTokenId())) {
-        BitbucketUser user = bitbucketServerApiClient.getUser(params.getToken());
-        return Optional.of(Pair.of(Boolean.TRUE, user.getName()));
-      }
-      // Token is added by OAuth. Token id is available.
-      BitbucketPersonalAccessToken bitbucketPersonalAccessToken =
-          bitbucketServerApiClient.getPersonalAccessToken(
-              params.getScmTokenId(), params.getToken());
-      return Optional.of(
-          Pair.of(
-              DEFAULT_TOKEN_SCOPE.equals(bitbucketPersonalAccessToken.getPermissions())
-                  ? Boolean.TRUE
-                  : Boolean.FALSE,
-              bitbucketPersonalAccessToken.getUser().getName()));
+      BitbucketUser user = bitbucketServerApiClient.getUser(params.getToken());
+      return Optional.of(Pair.of(Boolean.TRUE, user.getName()));
     } catch (ScmItemNotFoundException | ScmUnauthorizedException | ScmCommunicationException e) {
       return Optional.empty();
     }
