@@ -44,6 +44,7 @@ import org.eclipse.che.api.factory.server.urlfactory.RemoteFactoryUrl;
 import org.eclipse.che.api.factory.server.urlfactory.URLFactoryBuilder;
 import org.eclipse.che.api.factory.shared.dto.FactoryDevfileV2Dto;
 import org.eclipse.che.api.factory.shared.dto.FactoryDto;
+import org.eclipse.che.api.factory.shared.dto.ScmInfoDto;
 import org.eclipse.che.api.workspace.server.devfile.FileContentProvider;
 import org.eclipse.che.api.workspace.server.devfile.URLFetcher;
 import org.eclipse.che.api.workspace.shared.dto.devfile.DevfileDto;
@@ -145,22 +146,17 @@ public class BitbucketFactoryParametersResolverTest {
 
     String bitbucketUrl = "https://bitbucket.org/eclipse/che";
 
-    FactoryDto computedFactory = generateDevfileFactory();
-
-    when(urlFactoryBuilder.buildDefaultDevfile(any())).thenReturn(computedFactory.getDevfile());
-
     when(urlFactoryBuilder.createFactoryFromDevfile(
             any(RemoteFactoryUrl.class), any(), anyMap(), anyBoolean()))
         .thenReturn(Optional.empty());
     Map<String, String> params = ImmutableMap.of(URL_PARAMETER_NAME, bitbucketUrl);
     // when
-    FactoryDto factory = (FactoryDto) bitbucketFactoryParametersResolver.createFactory(params);
+    FactoryDevfileV2Dto factory =
+        (FactoryDevfileV2Dto) bitbucketFactoryParametersResolver.createFactory(params);
     // then
-    verify(urlFactoryBuilder).buildDefaultDevfile(eq("che"));
-    assertEquals(factory, computedFactory);
-    SourceDto source = factory.getDevfile().getProjects().get(0).getSource();
-    assertEquals(source.getLocation(), bitbucketUrl + ".git");
-    assertEquals(source.getBranch(), null);
+    ScmInfoDto scmInfo = factory.getScmInfo();
+    assertEquals(scmInfo.getRepositoryUrl(), bitbucketUrl + ".git");
+    assertEquals(scmInfo.getBranch(), null);
   }
 
   @Test
