@@ -127,18 +127,14 @@ public abstract class AbstractGithubPersonalAccessTokenFetcher
 
   public PersonalAccessToken refreshPersonalAccessToken(Subject cheSubject, String scmServerUrl)
       throws ScmUnauthorizedException, ScmCommunicationException, UnknownScmProviderException {
-    return getOrRefreshPersonalAccessToken(cheSubject, scmServerUrl, true);
+    // Tokens generated via GitHub OAuth app do not have an expiration date, so we don't need to
+    // refresh them.
+    return fetchPersonalAccessToken(cheSubject, scmServerUrl);
   }
 
   @Override
   public PersonalAccessToken fetchPersonalAccessToken(Subject cheSubject, String scmServerUrl)
       throws ScmUnauthorizedException, ScmCommunicationException, UnknownScmProviderException {
-    return getOrRefreshPersonalAccessToken(cheSubject, scmServerUrl, false);
-  }
-
-  private PersonalAccessToken getOrRefreshPersonalAccessToken(
-      Subject cheSubject, String scmServerUrl, boolean forceRefreshToken)
-      throws ScmUnauthorizedException, ScmCommunicationException, UnknownScmProviderException {
     OAuthToken oAuthToken;
 
     if (githubApiClient == null || !githubApiClient.isConnected(scmServerUrl)) {
@@ -146,10 +142,7 @@ public abstract class AbstractGithubPersonalAccessTokenFetcher
       return null;
     }
     try {
-      oAuthToken =
-          forceRefreshToken
-              ? oAuthAPI.refreshToken(providerName)
-              : oAuthAPI.getOrRefreshToken(providerName);
+      oAuthToken = oAuthAPI.getOrRefreshToken(providerName);
       String tokenName = NameGenerator.generate(OAUTH_2_PREFIX, 5);
       String tokenId = NameGenerator.generate("id-", 5);
       Optional<Pair<Boolean, String>> valid =
