@@ -87,9 +87,21 @@ public class GitlabOAuthTokenFetcher implements PersonalAccessTokenFetcher {
     }
   }
 
+  @Override
+  public PersonalAccessToken refreshPersonalAccessToken(Subject cheSubject, String scmServerUrl)
+      throws ScmUnauthorizedException, ScmCommunicationException, UnknownScmProviderException {
+    return fetchOrRefreshPersonalAccessToken(cheSubject, scmServerUrl, true);
+  }
+
   @Override
   public PersonalAccessToken fetchPersonalAccessToken(Subject cheSubject, String scmServerUrl)
       throws ScmUnauthorizedException, ScmCommunicationException, UnknownScmProviderException {
+    return fetchOrRefreshPersonalAccessToken(cheSubject, scmServerUrl, false);
+  }
+
+  private PersonalAccessToken fetchOrRefreshPersonalAccessToken(
+      Subject cheSubject, String scmServerUrl, boolean forceRefreshToken)
+      throws ScmUnauthorizedException, ScmCommunicationException, UnknownScmProviderException {
     scmServerUrl = StringUtils.trimEnd(scmServerUrl, '/');
     GitlabApiClient gitlabApiClient = getApiClient(scmServerUrl);
     if (gitlabApiClient == null || !gitlabApiClient.isConnected(scmServerUrl)) {
@@ -105,7 +117,10 @@ public class GitlabOAuthTokenFetcher implements PersonalAccessTokenFetcher {
     }
     OAuthToken oAuthToken;
     try {
-      oAuthToken = oAuthAPI.getToken(OAUTH_PROVIDER_NAME);
+      oAuthToken =
+          forceRefreshToken
+              ? oAuthAPI.refreshToken(OAUTH_PROVIDER_NAME)
+              : oAuthAPI.getOrRefreshToken(OAUTH_PROVIDER_NAME);
       String tokenName = NameGenerator.generate(OAUTH_2_PREFIX, 5);
       String tokenId = NameGenerator.generate("id-", 5);
       Optional<Pair<Boolean, String>> valid =
