@@ -27,7 +27,6 @@ import static org.mockito.Mockito.when;
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertFalse;
 import static org.testng.Assert.assertNotNull;
-import static org.testng.Assert.assertNull;
 import static org.testng.Assert.assertTrue;
 
 import com.google.common.collect.ImmutableMap;
@@ -42,6 +41,7 @@ import org.eclipse.che.api.factory.server.urlfactory.RemoteFactoryUrl;
 import org.eclipse.che.api.factory.server.urlfactory.URLFactoryBuilder;
 import org.eclipse.che.api.factory.shared.dto.FactoryDevfileV2Dto;
 import org.eclipse.che.api.factory.shared.dto.FactoryDto;
+import org.eclipse.che.api.factory.shared.dto.ScmInfoDto;
 import org.eclipse.che.api.workspace.server.devfile.URLFetcher;
 import org.eclipse.che.api.workspace.shared.dto.devfile.DevfileDto;
 import org.eclipse.che.api.workspace.shared.dto.devfile.MetadataDto;
@@ -114,22 +114,17 @@ public class GitlabFactoryParametersResolverTest {
 
     String gitlabUrl = "http://gitlab.2mcl.com/test/proj/repo.git";
 
-    FactoryDto computedFactory = generateDevfileFactory();
-
-    when(urlFactoryBuilder.buildDefaultDevfile(any())).thenReturn(computedFactory.getDevfile());
-
     when(urlFactoryBuilder.createFactoryFromDevfile(
             any(RemoteFactoryUrl.class), any(), anyMap(), anyBoolean()))
         .thenReturn(Optional.empty());
     Map<String, String> params = ImmutableMap.of(URL_PARAMETER_NAME, gitlabUrl);
     // when
-    FactoryDto factory = (FactoryDto) gitlabFactoryParametersResolver.createFactory(params);
+    FactoryDevfileV2Dto factory =
+        (FactoryDevfileV2Dto) gitlabFactoryParametersResolver.createFactory(params);
     // then
-    verify(urlFactoryBuilder).buildDefaultDevfile(eq("repo"));
-    assertEquals(factory, computedFactory);
-    SourceDto source = factory.getDevfile().getProjects().get(0).getSource();
-    assertEquals(source.getLocation(), gitlabUrl);
-    assertNull(source.getBranch());
+    ScmInfoDto scmInfo = factory.getScmInfo();
+    assertEquals(scmInfo.getRepositoryUrl(), gitlabUrl);
+    assertEquals(scmInfo.getBranch(), null);
   }
 
   @Test
