@@ -152,9 +152,12 @@ public class FactoryService extends Service {
           factoryParametersResolverHolder.getFactoryParametersResolver(
               singletonMap(URL_PARAMETER_NAME, url));
       if (!authorisationRequestManager.isStored(factoryParametersResolver.getProviderName())) {
-        personalAccessTokenManager.getAndStore(
-            // get the provider URL from the factory URL
-            factoryParametersResolver.parseFactoryUrl(url).getProviderUrl());
+        String scmServerUrl = factoryParametersResolver.parseFactoryUrl(url).getProviderUrl();
+        if (Boolean.parseBoolean(System.getenv("CHE_FORCE_REFRESH_PERSONAL_ACCESS_TOKEN"))) {
+          personalAccessTokenManager.forceRefreshPersonalAccessToken(scmServerUrl);
+        } else {
+          personalAccessTokenManager.getAndStore(scmServerUrl);
+        }
       }
     } catch (ScmCommunicationException
         | ScmConfigurationPersistenceException
